def  addition(a,b):
     return a+b

def  Substraction(a,b): 
     return a-b

def Divison(a,b): 
      return a/b

def Multiplication(a,b): 
      return a*b

def Modulus(a,b): 
      return a%b      
      
